All pastes #481693 Raw Edit

Someone

public text v1 · immutable
·published 2007-05-10 23:09 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Fri May 11 14:08:19 2007

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  precompiled interfaces  : true
  no ncurses color        : false
  query latest version    : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no recursion            : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  no kernel module        : false
  force SELinux           : default
  no X server check       : false
  force tls               : (not specified)
  X install prefix        : (not specified)
  X library install path  : (not specified)
  X module install path   : (not specified)
  OpenGL install prefix   : (not specified)
  OpenGL install libdir   : (not specified)
  utility install prefix  : (not specified)
  utility install libdir  : (not specified)
  doc install prefix      : (not specified)
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : (not specified)
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: No)
-> No precompiled kernel interface was found to match your kernel; this means
   that the installer will need to compile a new kernel interface.
-> Performing CC sanity check with CC="cc".
-> Performing CC version check with CC="cc".
-> Kernel source path: '/lib/modules/2.6.18-4-686/build'
-> Kernel output path: '/lib/modules/2.6.18-4-686/build'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Performing Xen check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nv.o nv
   -vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvidia.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h Modules.symvers
   rm -f -rf .tmp_versions
   rm -f Makefile
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/lib/modules/2.6.18-4-686/bu
   ild SYSOUT=/lib/modules/2.6.18-4-686/build'...
   sh ./conftest.sh "cc" "cc" /lib/modules/2.6.18-4-686/build /lib/modules/2.6.
   18-4-686/build cc_sanity_check full_output
   sh ./conftest.sh "cc" "cc" /lib/modules/2.6.18-4-686/build /lib/modules/2.6.
   18-4-686/build select_makefile full_output
   make --no-print-directory -f Makefile module
   
   NVIDIA: calling KBUILD...
   make CC=cc  KBUILD_VERBOSE=1 -C /lib/modules/2.6.18-4-686/build SUBDIRS=/tmp
   /selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv modules
   test -e include/linux/autoconf.h -a -e include/config/auto.conf || (		\
   	echo;								\
   	echo "  ERROR: Kernel configuration is invalid.";		\
   	echo "         include/linux/autoconf.h or include/config/auto.conf are mis
   sing.";	\
   	echo "         Run 'make oldconfig && make prepare' on kernel src to fix it
   .";	\
   	echo;								\
   	/bin/false)
   mkdir -p /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.tmp_vers
   ions
   rm -f /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.tmp_version
   s/*
   make -f scripts/Makefile.build obj=/tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755
   -pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /tmp/selfgz3869/NVI
   DIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.nv.o
   .d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KERNEL_
   _ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-protot
   ypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os -pipe -msoft-float 
   -mpreferred-stack-boundary=2  -march=i686 -mregparm=3 -ffreestanding -Iinclu
   de/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector -Wdeclar
   ation-after-statement -Wno-pointer-sign -I/tmp/selfgz3869/NVIDIA-Linux-x86-1
   .0-9755-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wc
   har-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror  -O -f
   no-common -msoft-float       -MD   -Wsign-compare -Wno-cast-qual -Wno-error 
   -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_MAJOR_VERSION=1 -DN
   V_MINOR_VERSION=0 -DNV_PATCHLEVEL=9755  -
   UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGAR
   T_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_
   PM_MESSAGE_T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_ST
   ATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT 
   -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESE
   NT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv)"  -D"KBU
   ILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9
   755-pkg1/usr/src/nv/.tmp_nv.o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1
   /usr/src/nv/nv.c
   In file included from include/linux/list.h:8,
                    from include/linux/lockdep.h:12,
                    from include/linux/spinlock_types.h:12,
                    from include/linux/spinlock.h:78,
                    from include/linux/capability.h:45,
                    from include/linux/sched.h:44,
                    from include/linux/module.h:9,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:564,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:77,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv.c:14:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:245: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.nv-v
   m.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KERN
   EL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-pro
   totypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os -pipe -msoft-flo
   at -mpreferred-stack-boundary=2  -march=i686 -mreg
   parm=3 -ffreestanding -Iinclude/asm-i386/mach-default -fomit-frame-pointer  
   -fno-stack-protector -Wdeclaration-after-statement -Wno-pointer-sign -I/tmp/
   selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv -Wall -Wimplicit -Wretu
   rn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith  -
   Wno-multichar  -Werror  -O -fno-common -msoft-float       -MD   -Wsign-compa
   re -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -D
   NVRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9755  -UDEBUG
   -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESE
   NT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESS
   AGE_T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRE
   SENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_RE
   MAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DM
   ODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_vm)"  -D"KBUILD_
   MODNAME=KBUILD_STR(nvidia)" -c -o /
   tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.tmp_nv-vm.o /tmp/s
   elfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/nv-vm.c
   In file included from include/linux/list.h:8,
                    from include/linux/lockdep.h:12,
                    from include/linux/spinlock_types.h:12,
                    from include/linux/spinlock.h:78,
                    from include/linux/capability.h:45,
                    from include/linux/sched.h:44,
                    from include/linux/module.h:9,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-vm.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:564,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:77,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-vm.c:14:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:245: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.os-a
   gp.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KER
   NEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-pr
   ototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os -pipe -msoft-fl
   oat -mpreferred-stack-boundary=2  -march=i686 -mregparm=3 -ffreestanding -Ii
   nclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector -Wde
   claration-after-statement -Wno-pointer-sign -I/tmp/selfgz3869/NVIDIA-Linux-x
   86-1.0-9755-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat
   -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror  -O
   -fno-common -msoft-float       -MD   -Wsign-compare -Wno-cast-qual -Wno-erro
   r -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_MAJOR_VERSION=1 
   -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9755  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SI
   GNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRE
   SENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_IRQ_HA
   NDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_
   PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DN
   V_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s
   " -D"KBUILD_BASENAME=KBUILD_STR(os_agp)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidi
   a)" -c -o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.tmp_os-
   agp.o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/os-agp.c
   In file included from include/linux/list.h:8,
                    from include/linux/lockdep.h:12,
                    from include/linux/spinlock_types.h:12,
                    from include/linux/spinlock.h:78,
                    from include/linux/capability.h:45,
                    from include/linux/sched.h:44,
                    from include/linux/module.h:9,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/os-agp.c:24:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:564,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:77,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/os-agp.c:24:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:245: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.os-i
   nterface.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -
   D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstr
   ict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common
    -Os -pipe -msoft-float -mpreferred-stack-boundary=2  -march=i686 -mregparm=
   3 -ffreestanding -Iinclude/asm-i386/mach-default -fomit-frame-pointer  -fno-
   stack-protector -Wdeclaration-after-statement -Wno-pointer-sign -I/tmp/selfg
   z3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-ty
   pe -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-m
   ultichar  -Werror  -O -fno-common -msoft-float       -MD   -Wsign-compare -W
   no-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM 
   -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9755  -UDEBUG -U_D
   EBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -
   DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_
   T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT
   -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_P
   FN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE
   -D"KBUILD_STR(s)=#s" -D"KBUILD_BAS
   ENAME=KBUILD_STR(os_interface)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o
   /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.tmp_os-interface.
   o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/os-interface.c
   In file included from include/linux/list.h:8,
                    from include/linux/lockdep.h:12,
                    from include/linux/spinlock_types.h:12,
                    from include/linux/spinlock.h:78,
                    from include/linux/capability.h:45,
                    from include/linux/sched.h:44,
                    from include/linux/module.h:9,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/os-interface.c:26:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:564,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:77,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/os-interface.c:26:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:245: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.os-r
   egistry.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D
   __KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstri
   ct-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os -pipe -mso
   ft-float -mpreferred-stack-boundary=2  -march=i686 -mregparm=3 -ffreestandin
   g -Iinclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector
   -Wdeclaration-after-statement -Wno-pointer-sign -I/tmp/selfgz3869/NVIDIA-Lin
   ux-x86-1.0-9755-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wfo
   rmat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werro
   r  -O -fno-common -msoft-float       -MD   -Ws
   ign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DM
   ODULE  -DNVRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9755
    -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPG
   ART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DN
   V_PM_MESSAGE_T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_
   STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESEN
   T -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRE
   SENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_registr
   y)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz3869/NVIDIA-Linu
   x-x86-1.0-9755-pkg1/usr/src/nv/.tmp_os-registry.o /tmp/selfgz3869/NVIDIA-Lin
   ux-x86-1.0-9755-pkg1/usr/src/nv/os-registry.c
   In file included from include/linux/list.h:8,
                    from include/linux/lockdep.h:12,
                    from include/linux/spinlock_types.h:12,
                    from include/linux/spinlock.h:78,
                    from include/linux/capability.h:45,
                    from include/linux/sched.h:44,
                    from include/linux/module.h:9,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/os-registry.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:564,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:77,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/os-registry.c:14:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:245: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.nv-i
   2c.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KER
   NEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-pr
   ototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os -pipe -msoft-fl
   oat -mpreferred-stack-boundary=2  -march=i686 -mregparm=3 -ffreestanding -Ii
   nclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector -Wde
   claration-after-statement -Wno-pointer-sign -I/tmp/selfgz3869/NVIDIA-Linux-x
   86-1.0-9755-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat
   -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror  -O
   -fno-common -msoft-float       -MD   -Wsign-compare -Wno-cast-qual -Wno-erro
   r -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_MAJOR_VERSION=1 -
   DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9755  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIG
   NAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRES
   ENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_IRQ_HAN
   DLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_P
   RESENT -DNV_OLD_MM_KGDB_BREAKPOINT_P
   RESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_
   4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_i2
   c)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz3869/NVIDIA-Linu
   x-x86-1.0-9755-pkg1/usr/src/nv/.tmp_nv-i2c.o /tmp/selfgz3869/NVIDIA-Linux-x8
   6-1.0-9755-pkg1/usr/src/nv/nv-i2c.c
   In file included from include/linux/list.h:8,
                    from include/linux/lockdep.h:12,
                    from include/linux/spinlock_types.h:12,
                    from include/linux/spinlock.h:78,
                    from include/linux/capability.h:45,
                    from include/linux/sched.h:44,
                    from include/linux/module.h:9,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-i2c.c:8:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:564,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-linux.h:77,
                    from /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src
   /nv/nv-i2c.c:8:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:245: warning: wrong type argument to increment
     ld -m elf_i386 -m elf_i386  -r -o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-975
   5-pkg1/usr/src/nv/nvidia.o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/us
   r/src/nv/nv-kernel.o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/
   nv/nv.o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/nv-vm.o /t
   mp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/os-agp.o /tmp/selfgz
   3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/os-interface.o /tmp/selfgz386
   9/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/os-registry.o /tmp/selfgz3869/NV
   IDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/nv-i2c.o
     Building modules, stage 2.
   make -rR -f /usr/src/linux-headers-2.6.18-4-686/scripts/Makefile.modpost
     scripts/mod/modpost -m  -i /usr/src/linux-headers-2.6.18-4-686/Module.symv
   ers -I /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/Module.symv
   ers -o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/Module.symv
   ers /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/nvidia.o
     cc -Wp,-MD,/tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/.nvid
   ia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D_
   _KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstric
   t-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os -pipe -msof
   t-float -mpreferred-stack-boundary=2  -march=i686 -mregparm=3 -ffreestanding
   -Iinclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector -
   Wdeclaration-after-statement -Wno-pointer-sign    -D"KBUILD_STR(s)=#s" -D"KB
   UILD_BASENAME=KBUILD_STR(nvidia.mod)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)"
   -DMODULE -c -o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr
   /src/nv/nvidia.mod.o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/
   nv/nvidia.mod.c
     ld -m elf_i386 -m elf_i386 -r -o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755
   -pkg1/usr/src/nv/nvidia.ko /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/us
   r/src/nv/nvidia.o /tmp/selfgz3869/NVIDIA-Linux-x86-1.0-9755-pkg1/usr/src/nv/
   nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
-> Kernel messages:
   ali15x3_smbus 0000:00:1e.1: ALI15X3_smb region uninitialized - upgrade BIOS
   or use force_addr=0xaddr
   ali15x3_smbus 0000:00:1e.1: ALI15X3 not detected, module not inserted.
   ACPI: PCI Interrupt 0000:00:1d.0[C] -> GSI 22 (level, low) -> IRQ 233
   input: ImPS/2 Generic Wheel Mouse as /class/input/input2
   ts: Compaq touchscreen protocol output
   Adding 2097140k swap on /dev/hda2.  Priority:-1 extents:1 across:2097140k
   EXT3 FS on hda6, internal journal
   loop: loaded (max 8 devices)
   device-mapper: ioctl: 4.7.0-ioctl (2006-06-24) initialised:
   dm-devel@redhat.com
   FAT: utf8 is not a recommended IO charset for FAT filesystems, filesystem
   will be case sensitive!
   kjournald starting.  Commit interval 5 seconds
   EXT3-fs warning: maximal mount count reached, running e2fsck is recommended
   EXT3 FS on hda5, internal journal
   EXT3-fs: mounted filesystem with ordered data mode.
   FAT: utf8 is not a recommended IO charset for FAT filesystems, filesystem
   will be case sensitive!
   FAT: utf8 is not a recommended IO charset for FAT filesystems, filesystem
   will be case sensitive!
   uli526x: eth1 NIC Link is Up 100 Mbps Full duplex
   NET: Registered protocol family 10
   lo: Disabled Privacy Extensions
   IPv6 over IPv4 tunneling driver
   eth1: no IPv6 routers present
   nvidia: module license 'NVIDIA' taints kernel.
   ACPI: PCI Interrupt 0000:01:00.0[A] -> GSI 18 (level, low) -> IRQ 193
   PCI: Setting latency timer of device 0000:01:00.0 to 64
   NVRM: loading NVIDIA UNIX x86 Kernel Module  1.0-9755  Mon Feb 26 23:21:15
   PST 2007
-> Installing both new and classic TLS OpenGL libraries.
-> Searching for conflicting X files:
-> done.
-> Searching for conflicting OpenGL files:
-> done.
-> Installing 'NVIDIA Accelerated Graphics Driver for Linux-x86' (1.0-9755):
   executing: '/sbin/ldconfig'...
   executing: '/sbin/depmod -aq'...
-> done.
-> Driver file installation is complete.
-> Running post-install sanity check:
-> done.
-> Post-install sanity check passed.
-> Shared memory test passed.
-> Running runtime sanity check:
-> done.
-> Runtime sanity check passed.
-> Would you like to run the nvidia-xconfig utility to automatically update you
   r X configuration file so that the NVIDIA X driver will be used when you res
   tart X?  Any pre-existing X configuration file will be backed up. (Answer: Y
   es)
-> Your X configuration file has been successfully updated.  Installation of
   the NVIDIA Accelerated Graphics Driver for Linux-x86 (version: 1.0-9755) is
   now complete.